==> nextcloud-31.0.9.tgz: nextcloud/apps/text/l10n/uz.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fayl yuklangan edi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yuklangan fayl php.ini dagi php-dagi upload_max_filesize direktivasidan oshadi",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yuklangan fayl HTML shaklida ko'rsatilgan MAX_FILE_SIZE direktivasidan oshadi",
    "The file was only partially uploaded" : "Fayl faqat qisman yuklandi",
    "No file was uploaded" : "Fayl yuklanmadi",
    "Missing a temporary folder" : "Vaqtinchalik papka etishmayapti",
    "Could not write file to disk" : "Faylni diskka yozib bo'lmadi",
    "A PHP extension stopped the file upload" : "PHP kengaytmasi faylni yuklashni to'xtatdi",
    "File not found" : "File not found",
    "Text" : "Matn",
    "Nextcloud Assistant" : "Next bulut yordamchisi",
    "Translate" : "Tarjima",
    "Offline" : "Offline",
    "Saving …" : "Saqlanmoqda...",
    "Saved" : "Saved",
    "Unsaved changes" : "Saqlanmagan o'zgarishlar",
    "Link" : "Link",
    "Undo" : "Bekor qilish",
    "Save changes" : "Save changes",
    "Cancel" : "Bekor qilish",
    "URL" : "URL",
    "to" : "пф",
    "Upload" : "Yuklash",
    "Edit" : "Tahrirlash",
    "Source code" : "Manba kodi",
    "Delete this attachment" : "Ushbu biriktirmani oʻchirib tashlang",
    "Done" : "Done",
    "Lists" : "Ro'yxatlar",
    "Table" : "Jadval",
    "Details" : "Details",
    "Formatting" : "Formatlash",
    "Choose" : "Tanlang",
    "Choose {file}" : " {file}ta tanlash",
    "Success" : "Success"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.12.tgz: nextcloud/apps/text/l10n/uz.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fayl yuklangan edi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yuklangan fayl php.ini dagi php-dagi upload_max_filesize direktivasidan oshadi",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yuklangan fayl HTML shaklida ko'rsatilgan MAX_FILE_SIZE direktivasidan oshadi",
    "The file was only partially uploaded" : "Fayl faqat qisman yuklandi",
    "No file was uploaded" : "Fayl yuklanmadi",
    "Missing a temporary folder" : "Vaqtinchalik papka etishmayapti",
    "Could not write file to disk" : "Faylni diskka yozib bo'lmadi",
    "A PHP extension stopped the file upload" : "PHP kengaytmasi faylni yuklashni to'xtatdi",
    "File not found" : "File not found",
    "Text" : "Matn",
    "Reload" : "Qayta yuklash",
    "Copy link" : "Havolani nusxalash",
    "Offline" : "Offline",
    "Saving …" : "Saqlanmoqda...",
    "Saved" : "Saved",
    "Unsaved changes" : "Saqlanmagan o'zgarishlar",
    "Keyboard shortcuts" : "Klaviatura yorliqlari",
    "Link" : "Link",
    "Undo" : "Bekor qilish",
    "Save changes" : "Save changes",
    "Cancel" : "Bekor qilish",
    "URL" : "URL",
    "Save" : "Saqlash",
    "Translate" : "Tarjima",
    "Nextcloud Assistant" : "Next bulut yordamchisi",
    "to" : "пф",
    "Upload" : "Yuklash",
    "Edit" : "Tahrirlash",
    "Source code" : "Manba kodi",
    "Delete this attachment" : "Ushbu biriktirmani oʻchirib tashlang",
    "Done" : "Bajarildi",
    "Lists" : "Ro'yxatlar",
    "Table" : "Jadval",
    "Details" : "Details",
    "Option" : "Variant",
    "Formatting" : "Formatlash",
    "Choose" : "Tanlang",
    "Choose {file}" : " {file}ta tanlash"
},
"nplurals=1; plural=0;");
